@@ -492,7 +492,7 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
                 if ((*it).isEmpty() || (*it) == "yes" || (*it) == "vending_machine") {
                     continue;
                 }
-                out.push_back(translateValue((*it).constData(), amenity_map, "OSM::amenity/shop"));
+                out.push_back(translateValue((*it).constData(), amenity_map));
             }
 
             std::sort(out.begin(), out.end());
@@ -512,13 +512,13 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
             }
             return QLocale().createSeparatedList(l);
         }
-        case Cuisine: return translateValues(m_element.tagValue("cuisine"), cuisine_map, "OSM::cuisine");
+        case Cuisine: return translateValues(m_element.tagValue("cuisine"), cuisine_map);
         case Diet:
         {
             QStringList l;
             for (const auto &d : diet_type_map) {
                 const auto v = m_element.tagValue(d.keyName);
-                const auto label = i18nc("OSM::diet_type", d.label);
+                const auto label = d.label.toString();
                 if (v == "yes") {
                     l.push_back(label);
                 } else if (v == "only") {
@@ -529,7 +529,7 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
             }
             return l.join(QLatin1String(", "));
         }
-        case Takeaway: return QString::fromUtf8(m_element.tagValue("takeaway")); // TODO decode (yes/only/no) and translate
+        case Takeaway: return translatedBoolValue(m_element.tagValue("takeaway")); // TODO decode (yes/only/no) and translate
         case Socket:
         {
             QStringList l;
@@ -539,7 +539,7 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
                     continue;
                 }
 
-                auto s = i18nc("OSM::charging_station_socket", socket.label);
+                auto s = socket.label.toString();
 
                 QStringList details;
                 if (value != "yes") {
@@ -575,23 +575,12 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
         {
             const auto total = m_element.tagValue("mx:realtime_available").toInt();
             QStringList types;
-            // there's no I18N_NOOP plural variants, so we have to use this more expensive approach
-            struct {
-                const char *tagName;
-                KLocalizedString msg;
-            } static const available_vehicles_map[] = {
-                { "mx:realtime_available:bike", ki18ncp("available rental vehicles", "%1 bike", "%1 bikes") },
-                { "mx:realtime_available:pedelec", ki18ncp("available rental vehicles", "%1 pedelec", "%1 pedelecs") },
-                { "mx:realtime_available:scooter", ki18ncp("available rental vehicles", "%1 kick scooter", "%1 kick scooters") },
-                { "mx:realtime_available:motorcycle", ki18ncp("available rental vehicles", "%1 moped", "%1 mopeds") },
-                { "mx:realtime_available:car", ki18ncp("available rental vehicles", "%1 car", "%1 cars") },
-            };
             for (const auto &v : available_vehicles_map) {
-                const auto b = m_element.tagValue(v.tagName);
+                const auto b = m_element.tagValue(v.keyName);
                 if (b.isEmpty()) {
                     continue;
                 }
-                types.push_back(v.msg.subs(b.toInt()).toString());
+                types.push_back(v.label.subs(b.toInt()).toString());
             }
 
             if (types.isEmpty()) {
@@ -628,11 +617,11 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
                 if (v.isEmpty() || v == "no") {
                     continue;
                 }
-                l.push_back(i18nc("OSM::charging_station_authentication", auth.label));
+                l.push_back(auth.label.toString());
             }
             return QLocale().createSeparatedList(l);
         }
-        case BicycleParking: return translateValues(m_element.tagValue("bicycle_parking"), bicycle_parking_map, "OSM::bicycle_parking");
+        case BicycleParking: return translateValues(m_element.tagValue("bicycle_parking"), bicycle_parking_map);
         case Capacity: return QString::fromUtf8(m_element.tagValue("capacity"));
         case CapacityDisabled: return capacitryValue("capacity:disabled");
         case CapacityWomen: return capacitryValue("capacity:women");
@@ -640,9 +629,8 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
         case CapacityCharing: return capacitryValue("capacity:charging");
         case MaxStay: return QString::fromUtf8(m_element.tagValue("maxstay"));
         case DiaperChangingTable:
-            // TODO bool value translation
             // TODO look for changing_table:location too
-            return QString::fromUtf8(m_element.tagValue("changing_table", "diaper"));
+            return translatedBoolValue(m_element.tagValue("changing_table", "diaper"));
         case Wikipedia: return wikipediaUrl(m_element.tagValue("wikipedia", "brand:wikipedia", QLocale()));
         case Address: return QVariant::fromValue(OSMAddress(m_element));
         case Phone: return QString::fromUtf8(m_element.tagValue("contact:phone", "phone", "telephone", "operator:phone"));
@@ -653,7 +641,7 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
             const auto coins = m_element.tagValue("payment:coins");
             const auto notes = m_element.tagValue("payment:notes");
             if (coins.isEmpty() && notes.isEmpty()) {
-                return m_element.tagValue("payment:cash"); // TODO decode bool
+                return translatedBoolValue(m_element.tagValue("payment:cash"));
             }
             if (coins == "yes" && notes == "yes") {
                 return i18n("yes");
@@ -679,7 +667,7 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
             } else {
                 wheelchair = m_element.tagValue("wheelchair");
             }
-            const auto a = translateValue(wheelchair.constData(), wheelchair_map, "OSM::wheelchair_access");
+            const auto a = translateValue(wheelchair.constData(), wheelchair_map);
             const auto d = QString::fromUtf8(m_element.tagValue("wheelchair:description", QLocale()));
             if (!d.isEmpty()) {
                 return QString(a + QLatin1String(" (") + d + QLatin1Char(')'));
@@ -746,7 +734,7 @@ QString OSMElementInformationModel::paymentMethodList(OSMElementInformationModel
             continue;
         }
         if (m_element.tagValue(payment.keyName) == "yes") {
-            l.push_back(i18nc("OSM::payment_method", payment.label));
+            l.push_back(payment.label.toString());
         }
     }
     std::sort(l.begin(), l.end());
@@ -794,11 +782,16 @@ QUrl OSMElementInformationModel::wikipediaUrl(const QByteArray &wp) const
 QString OSMElementInformationModel::capacitryValue(const char *prop) const
 {
     const auto v = m_element.tagValue(prop);
-    if (v == "yes") {
+    return translatedBoolValue(v);
+}
+
+QString OSMElementInformationModel::translatedBoolValue(const QByteArray &value) const
+{
+    if (value == "yes") {
         return i18n("yes");
     }
-    if (v == "no") {
+    if (value == "no") {
         return i18n("no");
     }
-    return QString::fromUtf8(v);
+    return QString::fromUtf8(value);
 }
